aboutsummaryrefslogtreecommitdiffstats
path: root/params/denomination.go
diff options
context:
space:
mode:
Diffstat (limited to 'params/denomination.go')
-rw-r--r--params/denomination.go16
1 files changed, 5 insertions, 11 deletions
diff --git a/params/denomination.go b/params/denomination.go
index 1a309827d..fb4da7f41 100644
--- a/params/denomination.go
+++ b/params/denomination.go
@@ -17,18 +17,12 @@
package params
// These are the multipliers for ether denominations.
// Example: To get the wei value of an amount in 'douglas', use
//
-// new(big.Int).Mul(value, big.NewInt(params.Douglas))
+// new(big.Int).Mul(value, big.NewInt(params.GWei))
//
const (
- Wei = 1
- Ada = 1e3
- Babbage = 1e6
- Shannon = 1e9
- Szabo = 1e12
- Finney = 1e15
- Ether = 1e18
- Einstein = 1e21
- Douglas = 1e42
+ Wei = 1
+ GWei = 1e9
+ Ether = 1e18
)
@@ -17,18 +17,12 @@
package params
// These are the multipliers for ether denominations.
-// Example: To get the wei value of an amount in 'douglas', use
+// Example: To get the wei value of an amount in 'gwei', use
//